@@ -18,7 +18,6 @@
 
 #include <bakery/App/App_WithDoc.h>
 #include <bakery/App/Dialog_OfferSave.h>
-#include <bakery/App/Dialog_OverwriteFile.h>
 #include <gconfmm.h>
 #include <libgnomevfsmm.h>
 #include <libintl.h>
@@ -70,6 +69,37 @@ void App_WithDoc::on_menu_file_close()
     ui_hide(); //The AppInstanceManager will delete it.
 }
 
+bool App_WithDoc::open_document_from_data(const guchar* data, std::size_t length)
+{
+  const bool bTest = m_pDocument->load_from_data(data, length);
+
+  bool bOpenFailed = false;
+  if(!bTest) //if open failed.
+    bOpenFailed = true;
+  else
+  {
+    //if open succeeded then let the App respond:
+    const bool test = on_document_load();
+    if(!test)
+      bOpenFailed = true; //The application didn't like something about the just-loaded document.
+    else
+    {
+      update_window_title();
+      set_document_modified(false); //disables menu and toolbar Save items.
+
+      return true; //success.
+    }
+  }
+
+  if(bOpenFailed)
+  {
+    ui_warning(gettext("Open failed."), gettext("The document could not be opened."));
+
+    return false; //failed.
+  }
+  else
+    return true;
+}
 
 bool App_WithDoc::open_document(const Glib::ustring& file_uri)
 {
@@ -201,6 +231,7 @@ bool App_WithDoc::file_exists(const Glib::ustring& uri)
   {
     // Try to open the input file.
     Gnome::Vfs::Handle read_handle;
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
     try
     {
       read_handle.open(uri, Gnome::Vfs::OPEN_READ);
@@ -212,6 +243,11 @@ bool App_WithDoc::file_exists(const Glib::ustring& uri)
     {
       return false; //It does not exist.
     }
+#else
+      std::auto_ptr<Gnome::Vfs::exception> error;
+      read_handle.open(uri, Gnome::Vfs::OPEN_READ, error);
+      if(error.get() != NULL) return false;
+#endif
   }
 }
 
@@ -498,5 +534,5 @@ void App_WithDoc::document_history_remove(const Glib::ustring& file_uri)
   //Override this.
 }
 
-
 } //namespace
+
