@@ -25,7 +25,6 @@
 
 #include <bakery/App/GtkDialogs.h>
 #include <bakery/App/Dialog_OfferSave.h>
-#include <bakery/App/Dialog_OverwriteFile.h>
 #include <bakery/App/App_Gtk.h>
 #include <gtkmm/stock.h>
 #include <gtkmm/messagedialog.h>
@@ -42,19 +41,16 @@ void GtkDialogs::ui_warning(App& app, const Glib::ustring& text, const Glib::ust
   Gtk::Window* pWindow = dynamic_cast<Gtk::Window*>(&app);
 
 #ifdef BAKERY_MAEMO_ENABLED
-  std::auto_ptr<Hildon::Note> note;
-  if(pWindow) note.reset(new Hildon::Note(Hildon::NOTE_TYPE_INFORMATION, *pWindow, text, Gtk::StockID(Gtk::Stock::DIALOG_WARNING)));
-  else note.reset(new Hildon::Note(Hildon::NOTE_TYPE_INFORMATION, text, Gtk::Stock::DIALOG_WARNING));
-  Gtk::Dialog& dialog = *note;
+  Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, text, Gtk::Stock::DIALOG_WARNING));
 #else
   Gtk::MessageDialog dialog(App_Gtk::util_bold_message(text), true /* use markup */, Gtk::MESSAGE_WARNING);
   dialog.set_secondary_text(secondary_text);
 
   dialog.set_title(""); //The HIG says that alert dialogs should not have titles. The default comes from the message type.
+#endif
 
   if(pWindow)
     dialog.set_transient_for(*pWindow);
-#endif
 
   dialog.run();
 }
@@ -62,33 +58,30 @@ void GtkDialogs::ui_warning(App& app, const Glib::ustring& text, const Glib::ust
 Glib::ustring GtkDialogs::ui_file_select_open(App& app, const Glib::ustring& starting_folder_uri)
 {
   Gtk::Window* pWindow = dynamic_cast<Gtk::Window*>(&app);
+
 #ifdef BAKERY_MAEMO_ENABLED
-  std::auto_ptr<Hildon::FileChooserDialog> hildon_dialog;
-  if(pWindow) hildon_dialog.reset(new Hildon::FileChooserDialog(*pWindow, Gtk::FILE_CHOOSER_ACTION_OPEN));
-  else hildon_dialog.reset(new Hildon::FileChooserDialog(Gtk::FILE_CHOOSER_ACTION_OPEN));
-  Hildon::FileChooserDialog& fileChooser_Open = *hildon_dialog;
+  Hildon::FileChooserDialog fileChooser_Open(Gtk::FILE_CHOOSER_ACTION_OPEN));
 #else
   Gtk::FileChooserDialog fileChooser_Open(gettext("Open Document"), Gtk::FILE_CHOOSER_ACTION_OPEN);
-  if(pWindow)
-    fileChooser_Open.set_transient_for(*pWindow);
-
   fileChooser_Open.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
   fileChooser_Open.add_button(Gtk::Stock::OPEN, Gtk::RESPONSE_OK);
-
   fileChooser_Open.set_default_response(Gtk::RESPONSE_OK);
 #endif // BAKERY_MAEMO_ENABLED
 
+  if(pWindow)
+    fileChooser_Open.set_transient_for(*pWindow);
+
   if(!starting_folder_uri.empty())
     fileChooser_Open.set_current_folder_uri(starting_folder_uri);
 
-  int response_id = fileChooser_Open.run();
+  const int response_id = fileChooser_Open.run();
   fileChooser_Open.hide();
   if(response_id != Gtk::RESPONSE_CANCEL)
   {
     return fileChooser_Open.get_uri();
   }
   else
-    return "";
+    return Glib::ustring();
 }
 
 static bool uri_is_writable(const Glib::RefPtr<const Gnome::Vfs::Uri>& uri)
@@ -114,27 +107,20 @@ static bool uri_is_writable(const Glib::RefPtr<const Gnome::Vfs::Uri>& uri)
 Glib::ustring GtkDialogs::ui_file_select_save(App& app, const Glib::ustring& old_file_uri)
 {
   Gtk::Window* pWindow = dynamic_cast<Gtk::Window*>(&app);
+
 #ifdef BAKERY_MAEMO_ENABLED
-  std::auto_ptr<Hildon::FileChooserDialog> hildon_dialog;
-  if(pWindow) hildon_dialog.reset(new Hildon::FileChooserDialog(*pWindow, Gtk::FILE_CHOOSER_ACTION_SAVE));
-  else hildon_dialog.reset(new Hildon::FileChooserDialog(Gtk::FILE_CHOOSER_ACTION_SAVE));
-  Hildon::FileChooserDialog& fileChooser_Save = *hildon_dialog;
+  Hildon::FileChooserDialog fileChooser_Save(Gtk::FILE_CHOOSER_ACTION_SAVE);
 #else
   Gtk::FileChooserDialog fileChooser_Save(gettext("Save Document"), Gtk::FILE_CHOOSER_ACTION_SAVE);
-
-  if(pWindow)
-    fileChooser_Save.set_transient_for(*pWindow);
-
   fileChooser_Save.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
   fileChooser_Save.add_button(Gtk::Stock::SAVE, Gtk::RESPONSE_OK);
-
   fileChooser_Save.set_default_response(Gtk::RESPONSE_OK);
-#endif // BAKERY_MAMEO_ENABLED
+#endif // BAKERY_MAEMO_ENABLED
+
+ if(pWindow)
+    fileChooser_Save.set_transient_for(*pWindow);
 
-#ifdef GTKMM_GEQ_2_10
-  // TODO: Use our home-frown Dialog_OverwriteFile if gtkmm is not >= 2.10
   fileChooser_Save.set_do_overwrite_confirmation(); //Ask the user if the file already exists.
-#endif // GTKMM_GEQ_2_10
 
   //Make the save dialog show the existing filename, if any:
   if(!old_file_uri.empty())
