@@ -37,6 +37,7 @@ public:
   Document();
   virtual ~Document();
 
+  //TODO: It's probably not useful for this to be virtual:
   /* Saves the data to disk.
    * Asks the View to update this document before saving to disk,
    * but you should probably ensure that the document is updated more regularly than this,
@@ -46,11 +47,20 @@ public:
    */
   virtual bool save();
 
-  /* Loads data from disk, then asks the View to update itself.
+  //TODO: It's probably not useful for this to be virtual:
+  /* Loads data from disk, using the URI (set with set_file_uri()) then asks the View to update itself.
    * bool indicates success.
    */
   virtual bool load();
 
+  //This can't be virtual because that would break ABI.
+  //Hopefully it doesn't need to be.
+  /* Loads data from disk, using the URI (set with set_file_uri()) then asks the View to update itself.
+   * bool indicates success.
+   */
+  bool load_from_data(const guchar* data, std::size_t length);
+
+
   virtual bool get_modified() const;
   virtual void set_modified(bool bVal = true);
 
@@ -63,7 +73,7 @@ public:
   virtual void set_contents(const Glib::ustring& strVal);
 
   virtual Glib::ustring get_file_uri_with_extension(const Glib::ustring& uri);
-  
+
   virtual Glib::ustring get_file_uri() const;
   virtual void set_file_uri(const Glib::ustring& file_uri, bool bEnforceFileExtension = false);
 
@@ -73,7 +83,7 @@ public:
 
   virtual bool get_read_only() const;
   virtual void set_read_only(bool bVal);
-  
+
   ///If you don't want to use a View, then don't use set_view().
   virtual void set_view(ViewBase* pView);
   virtual ViewBase* get_view();
