@@ -40,7 +40,9 @@ bool Document_XML::load_after()
   if(!bTest)
     return false; //Failed.
 
+#ifdef LIBXMLPP_EXCEPTIONS_ENABLED
   try
+#endif
   {
     //Link the parser to the XML text that was loaded:
     //m_DOM_Parser.setDoValidation(true);
@@ -50,15 +52,18 @@ bool Document_XML::load_after()
 
     m_DOM_Parser.parse_memory(m_strContents);
     m_pDOM_Document = m_DOM_Parser.get_document();
+    if(!m_pDOM_Document) return false;
 
     return true; //Success.
   }
+#ifdef LIBXMLPP_EXCEPTIONS_ENABLED
   catch(const std::exception& ex)
   {
     std::cerr << "XML Parser error: \n" << ex.what() << std::endl;
 
     return false; //Failed.
   }
+#endif
 }
 
 
@@ -82,21 +87,26 @@ bool Document_XML::save_before()
 
 bool Document_XML::set_xml(const Glib::ustring& strXML)
 { 
+#ifdef LIBXMLPP_EXCEPTIONS_ENABLED
   try
+#endif
   {
     if(m_strContents.empty())
       g_warning("Document_XML::set_xml(): parsing empty document.");
 
     m_DOM_Parser.parse_memory(m_strContents);
     m_pDOM_Document = m_DOM_Parser.get_document();
+    if(!m_pDOM_Document) return false;
 
     return true;	
   }
+#ifdef LIBXMLPP_EXCEPTIONS_ENABLED
   catch(const std::exception& ex)
   {
     std::cerr << "XML Parser error: \n" << ex.what() << std::endl;
     return false; //Failed.
   }
+#endif
 } 
 
 
@@ -110,17 +120,21 @@ Glib::ustring Document_XML::get_xml() const
 
 void Document_XML::Util_DOM_Write(Glib::ustring& refstrXML) const
 {
+#ifdef LIBXMLPP_EXCEPTIONS_ENABLED
   try
+#endif
   {
     if(m_write_formatted)
       refstrXML = m_pDOM_Document->write_to_string_formatted();
     else
       refstrXML = m_pDOM_Document->write_to_string();
   }
+#ifdef LIBXMLPP_EXCEPTIONS_ENABLED
   catch(xmlpp::exception& ex)
   {
     std::cerr << "Document_XML::Util_DOM_Write(): exception caught: " << ex.what() << std::endl;
   }
+#endif
 }
 
 Glib::ustring Document_XML::get_node_attribute_value(const xmlpp::Element* node, const Glib::ustring& strAttributeName)
