@@ -22,7 +22,7 @@
 #ifndef HEADER_SUBVIEW1
 #define HEADER_SUBVIEW1
 
-#include <gtk--/box.h>
+#include <gtkmm/box.h>
 #include "docexample.h"
 
 class SubView1 : 
