@@ -24,18 +24,17 @@
 SubView2::SubView2()
 :  m_Label("foo")
 {
+  //TODO: This bottom pane is horribly high:
   attach(m_Label, 0, 1, 0, 1);
   attach(m_Combo, 1, 2, 0, 1);
 
   //Set up combo:
-  std::vector<Glib::ustring> vecChoices;
-  vecChoices.push_back("abc");
-  vecChoices.push_back("def");
-  vecChoices.push_back("ghi");
-  m_Combo.set_popdown_strings(vecChoices);
+  m_Combo.append_text("abc");
+  m_Combo.append_text("def");
+  m_Combo.append_text("ghi");
   
   //Connect signals:
-  m_Combo.get_entry()->signal_changed().connect(SigC::slot(*this, &SubView2::on_Combo_changed));
+  m_Combo.signal_changed().connect(sigc::mem_fun(*this, &SubView2::on_Combo_changed));
  
   show_all();
 }
@@ -46,12 +45,12 @@ SubView2::~SubView2()
 
 void SubView2::load_from_document()
 {
-  m_Combo.get_entry()->set_text( get_document()->get_something_else() );
+  m_Combo.set_active_text( get_document()->get_something_else() );
 }
 
 void SubView2::save_to_document()
 {
-  const Glib::ustring& strText = m_Combo.get_entry()->get_text();
+  const Glib::ustring strText = m_Combo.get_active_text();
   get_document()->set_something_else(strText);
 }
 
