@@ -34,7 +34,17 @@ main(int argc, char* argv[])
 
   //Instantiate the window from the libglade file.
   //In a real application, the .glade file would be installed, and the path would be in a #define.
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create("example.glade", "window_main");
+#else
+  std::auto_ptr<Gnome::Glade::XmlError> error;
+  Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create("example.glade", "window_main", "", error);
+  if(error.get())
+  {
+    std::cerr << error->what() << std::endl;
+    return -1;
+  }
+#endif
   AppExample* pApp = 0;
   refXml->get_widget_derived("window_main", pApp);
     
